@@ -18,7 +18,6 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
-using System.Collections;
 using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.Browser;
@@ -28,22 +27,4 @@ internal sealed class GetClientWindowsCommand()
 
 public sealed class GetClientWindowsOptions : CommandOptions;
 
-public sealed record GetClientWindowsResult : EmptyResult, IReadOnlyList<ClientWindowInfo>
-{
-    internal GetClientWindowsResult(IReadOnlyList<ClientWindowInfo> clientWindows)
-    {
-        ClientWindows = clientWindows;
-    }
-
-    public IReadOnlyList<ClientWindowInfo> ClientWindows { get; }
-
-    public ClientWindowInfo this[int index] => ClientWindows[index];
-
-    public int Count => ClientWindows.Count;
-
-
-
-    public IEnumerator<ClientWindowInfo> GetEnumerator() => ClientWindows.GetEnumerator();
-
-    IEnumerator IEnumerable.GetEnumerator() => (ClientWindows as IEnumerable).GetEnumerator();
-}
+public sealed record GetClientWindowsResult(IReadOnlyList<ClientWindowInfo> ClientWindows) : EmptyResult;
