@@ -18,7 +18,6 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
-using System.Collections;
 using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.Browser;
@@ -28,20 +27,4 @@ internal sealed class GetUserContextsCommand()
 
 public class GetUserContextsOptions : CommandOptions;
 
-public sealed record GetUserContextsResult : EmptyResult, IReadOnlyList<UserContextInfo>
-{
-    internal GetUserContextsResult(IReadOnlyList<UserContextInfo> userContexts)
-    {
-        UserContexts = userContexts;
-    }
-
-    public IReadOnlyList<UserContextInfo> UserContexts { get; }
-
-    public UserContextInfo this[int index] => UserContexts[index];
-
-    public int Count => UserContexts.Count;
-
-    public IEnumerator<UserContextInfo> GetEnumerator() => UserContexts.GetEnumerator();
-
-    IEnumerator IEnumerable.GetEnumerator() => (UserContexts as IEnumerable).GetEnumerator();
-}
+public sealed record GetUserContextsResult(IReadOnlyList<UserContextInfo> UserContexts) : EmptyResult;
