@@ -22,4 +22,4 @@ using System;
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
 
 public sealed record NavigationInfo(BiDi BiDi, BrowsingContext Context, Navigation? Navigation, DateTimeOffset Timestamp, string Url)
-    : BrowsingContextEventArgs(BiDi, Context);
+    : BrowsingContextEventArgs(BiDi, Context), IBaseNavigationInfo;
