@@ -23,7 +23,7 @@ using System.Collections.Generic;
 namespace OpenQA.Selenium.BiDi.Network;
 
 internal sealed class ContinueRequestCommand(ContinueRequestParameters @params)
-    : Command<ContinueRequestParameters, EmptyResult>(@params, "network.continueRequest");
+    : Command<ContinueRequestParameters, ContinueRequestResult>(@params, "network.continueRequest");
 
 internal sealed record ContinueRequestParameters(Request Request, BytesValue? Body, IEnumerable<CookieHeader>? Cookies, IEnumerable<Header>? Headers, string? Method, string? Url) : Parameters;
 
@@ -39,3 +39,5 @@ public sealed class ContinueRequestOptions : CommandOptions
 
     public string? Url { get; set; }
 }
+
+public sealed record ContinueRequestResult : EmptyResult;
