@@ -19,6 +19,7 @@
 
 using OpenQA.Selenium.BiDi.BrowsingContext;
 using System;
+using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.Network;
 
@@ -29,5 +30,6 @@ public sealed record ResponseCompletedEventArgs(BiDi BiDi,
     long RedirectCount,
     RequestData Request,
     DateTimeOffset Timestamp,
-    ResponseData Response)
-    : BaseParametersEventArgs(BiDi, Context, IsBlocked, Navigation, RedirectCount, Request, Timestamp);
+    ResponseData Response,
+    IReadOnlyList<Intercept>? Intercepts)
+    : BaseParametersEventArgs(BiDi, Context, IsBlocked, Navigation, RedirectCount, Request, Timestamp, Intercepts);
