@@ -17,6 +17,10 @@
 // under the License.
 // </copyright>
 
+using OpenQA.Selenium.BiDi.Communication.Json.Converters;
+using System.Text.Json.Serialization;
+
 namespace OpenQA.Selenium.BiDi.Script;
 
+[JsonConverter(typeof(ChannelConverter))]
 public sealed record Channel(string Id);
