@@ -18,7 +18,9 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
+using OpenQA.Selenium.BiDi.Communication.Json.Converters.Polymorphic;
 using System;
+using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.Script;
 
@@ -40,6 +42,7 @@ public sealed class EvaluateOptions : CommandOptions
 //[JsonPolymorphic(TypeDiscriminatorPropertyName = "type")]
 //[JsonDerivedType(typeof(EvaluateResultSuccess), "success")]
 //[JsonDerivedType(typeof(EvaluateResultException), "exception")]
+[JsonConverter(typeof(EvaluateResultConverter))]
 public abstract record EvaluateResult : EmptyResult
 {
     public RemoteValue AsSuccessResult()
