@@ -22,8 +22,10 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.WebExtension;
 
 internal sealed class UninstallCommand(UninstallParameters @params)
-    : Command<UninstallParameters, EmptyResult>(@params, "webExtension.uninstall");
+    : Command<UninstallParameters, UninstallResult>(@params, "webExtension.uninstall");
 
 internal sealed record UninstallParameters(Extension Extension) : Parameters;
 
 public sealed class UninstallOptions : CommandOptions;
+
+public sealed record UninstallResult : EmptyResult;
