@@ -72,7 +72,6 @@ public class Proxy
 {
     private ProxyKind proxyKind = ProxyKind.Unspecified;
     private bool isAutoDetect;
-    private string? ftpProxyLocation;
     private string? httpProxyLocation;
     private string? proxyAutoConfigUrl;
     private string? sslProxyLocation;
@@ -116,11 +115,6 @@ public class Proxy
             }
         }
 
-        if (settings.TryGetValue("ftpProxy", out object? ftpProxyObj) && ftpProxyObj?.ToString() is string ftpProxy)
-        {
-            this.FtpProxy = ftpProxy;
-        }
-
         if (settings.TryGetValue("httpProxy", out object? httpProxyObj) && httpProxyObj?.ToString() is string httpProxy)
         {
             this.HttpProxy = httpProxy;
@@ -236,23 +230,6 @@ public class Proxy
         }
     }
 
-    /// <summary>
-    /// Gets or sets the value of the proxy for the FTP protocol.
-    /// </summary>
-    [JsonPropertyName("ftpProxy")]
-    [JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingDefault)]
-    public string? FtpProxy
-    {
-        get => this.ftpProxyLocation;
-
-        set
-        {
-            this.VerifyProxyTypeCompatilibily(ProxyKind.Manual);
-            this.proxyKind = ProxyKind.Manual;
-            this.ftpProxyLocation = value;
-        }
-    }
-
     /// <summary>
     /// Gets or sets the value of the proxy for the HTTP protocol.
     /// </summary>
@@ -493,11 +470,6 @@ public class Proxy
                 serializedDictionary["sslProxy"] = this.sslProxyLocation;
             }
 
-            if (!string.IsNullOrEmpty(this.ftpProxyLocation))
-            {
-                serializedDictionary["ftpProxy"] = this.ftpProxyLocation;
-            }
-
             if (!string.IsNullOrEmpty(this.socksProxyLocation))
             {
                 if (!this.socksVersion.HasValue)
