@@ -20,14 +20,13 @@
 using OpenQA.Selenium.Chrome;
 using System;
 
-namespace OpenQA.Selenium.Remote
+namespace OpenQA.Selenium.Remote;
+
+public class StableChannelRemoteChromeDriver : RemoteWebDriver
 {
-    public class StableChannelRemoteChromeDriver : RemoteWebDriver
+    public StableChannelRemoteChromeDriver()
+        : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new ChromeOptions())
     {
-        public StableChannelRemoteChromeDriver()
-            : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new ChromeOptions())
-        {
-            this.FileDetector = new LocalFileDetector();
-        }
+        this.FileDetector = new LocalFileDetector();
     }
 }
